@@ -7,27 +7,32 @@
  * Support : support@synerty.com
 """
 import uuid
+from datetime import datetime
+from typing import Dict
+from typing import List
 
 import pytz
-from abc import ABCMeta
-from datetime import datetime, timezone
-from typing import Dict, List
 
-from vortex.Tuple import Tuple, addTupleType, TupleField
+from vortex.Tuple import Tuple
+from vortex.Tuple import TupleField
+from vortex.Tuple import addTupleType
 from vortex.TupleSelector import TupleSelector
 
 
 class TupleActionABC(Tuple):
-    uuid = TupleField(comment="Uniquely generated id for this action",
-                      typingType=str)
-    dateTime = TupleField(comment="The datetime this action was created",
-                          typingType=datetime)
+    uuid: str = TupleField(
+        comment="Uniquely generated id for this action", typingType=str
+    )
+    dateTime: datetime = TupleField(
+        comment="The datetime this action was created", typingType=datetime
+    )
 
     def __init__(self, **kwargs):
         if not self.__tupleType__:
             raise NotImplementedError(
                 "TupleActionABC can not be instantiated,"
-                " please inherit it and implement a tuple")
+                " please inherit it and implement a tuple"
+            )
 
         Tuple.__init__(self, **kwargs)
 
@@ -40,25 +45,27 @@ class TupleActionABC(Tuple):
 
 @addTupleType
 class TupleGenericAction(TupleActionABC):
-    """ Tuple Generic Action
+    """Tuple Generic Action
 
     This is a generic action, to be used when the implementor doesn't want to implement
     concrete classes for each action type.
 
     """
+
     __tupleType__ = "vortex.TupleGenericAction"
 
-    key = TupleField(comment="An optional key for this action",
-                     typingType=str)
+    key = TupleField(comment="An optional key for this action", typingType=str)
+
+    data = TupleField(comment="Optional data for the update", typingType=str)
 
-    data = TupleField(comment="Optional data for the update",
-                      typingType=str)
 
 @addTupleType
 class TupleUpdateAction(TupleActionABC):
     __tupleType__ = "vortex.TupleUpdateAction"
 
-    tupleSelector = TupleField(comment="The tuple selector for this action",
-                               typingType=TupleSelector)
-    tupleChanges = TupleField(comment="An array of {old:v,new:v} dicts for the changes",
-                              typingType=List[Dict])
+    tupleSelector = TupleField(
+        comment="The tuple selector for this action", typingType=TupleSelector
+    )
+    tupleChanges = TupleField(
+        comment="An array of {old:v,new:v} dicts for the changes", typingType=List[Dict]
+    )
